@@ -117,6 +117,8 @@ Activity：活动来源
         :type Source: str
         :param Channel: 渠道：wechat | cloud
         :type Channel: str
+        :param EnvId: 环境ID
+        :type EnvId: str
         """
         self.PackageType = None
         self.Alias = None
@@ -127,6 +129,7 @@ Activity：活动来源
         self.ReqKey = None
         self.Source = None
         self.Channel = None
+        self.EnvId = None
 
 
     def _deserialize(self, params):
@@ -139,6 +142,7 @@ Activity：活动来源
         self.ReqKey = params.get("ReqKey")
         self.Source = params.get("Source")
         self.Channel = params.get("Channel")
+        self.EnvId = params.get("EnvId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -652,6 +656,8 @@ class EnvBaseInfo(AbstractModel):
         :type Region: str
         :param EnvType: 环境类型 tcbr ｜ run
         :type EnvType: str
+        :param SubnetIds: 子网id
+        :type SubnetIds: str
         """
         self.EnvId = None
         self.PackageType = None
@@ -661,6 +667,7 @@ class EnvBaseInfo(AbstractModel):
         self.Status = None
         self.Region = None
         self.EnvType = None
+        self.SubnetIds = None
 
 
     def _deserialize(self, params):
@@ -672,6 +679,7 @@ class EnvBaseInfo(AbstractModel):
         self.Status = params.get("Status")
         self.Region = params.get("Region")
         self.EnvType = params.get("EnvType")
+        self.SubnetIds = params.get("SubnetIds")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1279,12 +1287,18 @@ class ServerBaseInfo(AbstractModel):
         :type Status: str
         :param UpdateTime: 更新时间
         :type UpdateTime: str
+        :param AccessTypes: 公网访问类型
+        :type AccessTypes: list of str
+        :param CustomDomainNames: 展示自定义域名
+        :type CustomDomainNames: list of str
         """
         self.ServerName = None
         self.DefaultDomainName = None
         self.CustomDomainName = None
         self.Status = None
         self.UpdateTime = None
+        self.AccessTypes = None
+        self.CustomDomainNames = None
 
 
     def _deserialize(self, params):
@@ -1293,6 +1307,8 @@ class ServerBaseInfo(AbstractModel):
         self.CustomDomainName = params.get("CustomDomainName")
         self.Status = params.get("Status")
         self.UpdateTime = params.get("UpdateTime")
+        self.AccessTypes = params.get("AccessTypes")
+        self.CustomDomainNames = params.get("CustomDomainNames")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
